@@ -32,24 +32,37 @@ sub SUPER
 }
 
 package SUPER;
-{
-  $SUPER::VERSION = '1.20120705';
-}
 # ABSTRACT: control superclass method dispatch
-
+$SUPER::VERSION = '1.20190531';
 use strict;
 use warnings;
 
-use base 'Exporter';
-
-@SUPER::ISA    = 'Exporter';
-@SUPER::EXPORT = 'super';
-
 use Carp;
 
 use Scalar::Util 'blessed';
 use Sub::Identify ();
 
+BEGIN {
+    # Due to a perl bug (fixed in v5.17.4, commit 3c104e59), if SUPER.pm is
+    # loaded, perl can no longer find methods on parent when:
+    # 1) the invocant is "main" (or isa "main")
+    # 2) using the SUPER pseudo-class syntax (i.e. "main"->SUPER::...)
+    # We work around that bug by handling ->SUPER::... ourselves.
+    if ($] < 5.017004)
+    {
+        no strict 'refs';
+        *{"SUPER::AUTOLOAD"} = \&UNIVERSAL::SUPER;
+    }
+}
+
+# no need to use Exporter
+sub import
+{
+    my ($class) = @_;
+    my $caller  = caller();
+    do { no strict 'refs'; *{ $caller . '::super' } = \&super };
+}
+
 sub find_parent
 {
     my ($class, $method, $prune, $invocant) = @_;
@@ -183,8 +196,7 @@ such as:
 
     goto &{$_[0]->super('my_method')};
 
-if you don't like wasting precious stack frames. (Because C<super> returns a
-coderef, much like L<UNIVERSAL/can>, this doesn't break C<use strict 'refs'>.)
+if you don't like wasting precious stack frames.
 
 If you are using roles or mixins or otherwise pulling in methods from other
 packages that need to dispatch to their super methods, or if you want to pass
@@ -255,7 +267,7 @@ which you really want to dispatch.
 Created by Simon Cozens, C<simon@cpan.org>.  Copyright (c) 2003 Simon Cozens.
 
 Maintained by chromatic, E<lt>chromatic at wgz dot orgE<gt> after version 1.01.
-Copyright (c) 2004-2012 chromatic.
+Copyright (c) 2004-2019 chromatic.
 
 Thanks to Joshua ben Jore for bug reports and suggestions.
 
